@@ -45,7 +45,7 @@ class ProductAdmin(LogHistoryAdmin):
 
     list_display = [
         'id', 'get_name_tag', 'warehouse', 'manufacturer', 'category',
-        'printable_price', 'code', 'stock', 'is_active', 'tecdoc_tag',
+        'printable_price', 'code', 'stock', 'is_active', 'tecdoc_cell',
         'get_item_actions'
     ]
 
@@ -94,13 +94,6 @@ class ProductAdmin(LogHistoryAdmin):
             format_printable_price(item.price_retail, item.initial_currency)
         )
 
-    @template_list_item(
-        'products/admin/tecdoc.html', _('Tecdoc'))
-    def tecdoc_tag(self, item):
-        return {'object': item}
-
-    tecdoc_tag.admin_order_field = 'supplier_id'
-
     @template_list_item(
         'products/admin/list_item_actions.html', _('Actions'))
     def get_item_actions(self, item):
